@@ -1,9 +1,16 @@
-# Copyright 1998-2009 by Roger Bivand (Wald test suggested by Rein Halbersma,
+# Copyright 1998-2010 by Roger Bivand (Wald test suggested by Rein Halbersma,
 # output of correlations suggested by Michael Tiefelsdorf)
 #
 
 print.sarlm <- function(x, ...)
 {
+       if (x$type == "error") if (isTRUE(all.equal(x$lambda, x$interval[1])) ||
+            isTRUE(all.equal(x$lambda, x$interval[2]))) 
+            warning("lambda on interval bound - results should not be used")
+       if (x$type == "lag" || x$type == "mixed")
+            if (isTRUE(all.equal(x$rho, x$interval[1])) ||
+            isTRUE(all.equal(x$rho, x$interval[2]))) 
+            warning("rho on interval bound - results should not be used")
 	cat("\nCall:\n")
 	print(x$call)
 	cat("Type:", x$type, "\n")
@@ -17,8 +24,8 @@ summary.sarlm <- function(object, correlation = FALSE, Nagelkerke=FALSE,
  Hausman=FALSE, ...)
 {
 	if (object$type == "error" || ((object$type == "lag" || 
-		object$type == "mixed" || object$type == "sac")
-                && object$ase)) {
+		object$type == "mixed" || object$type == "sac" || 
+                object$type == "sacmixed") && object$ase)) {
 		object$coeftitle <- "(asymptotic standard errors)"
 		object$Coef <- cbind(object$coefficients, object$rest.se, 
 			object$coefficients/object$rest.se,
@@ -175,7 +182,7 @@ Hausman.test.sarlm <- function(object, ..., tol=NULL) {
     p.value <- 1 - pchisq(abs(statistic), parameter)
     method <- paste("Spatial Hausman test", fmeth)
     data.name <- strwrap(deparse(object$formula), exdent=4)
-    if (length(data.name) > 1) 
+    if (length(data.name) > 1L) 
         data.name <- paste(data.name, collapse="\n    ")
     res <- list(statistic = statistic, parameter = parameter, 
         p.value = p.value, method = method, data.name=data.name)
@@ -204,7 +211,7 @@ Hausman.test.gmsar <- function(object, ..., tol=NULL) {
     p.value <- 1 - pchisq(abs(statistic), parameter)
     method <- paste("Spatial Hausman test", fmeth)
     data.name <- strwrap(deparse(object$formula), exdent=4)
-    if (length(data.name) > 1) 
+    if (length(data.name) > 1L) 
         data.name <- paste(data.name, collapse="\n    ")
     res <- list(statistic = statistic, parameter = parameter, 
         p.value = p.value, method = method, data.name=data.name)
@@ -216,10 +223,17 @@ print.summary.sarlm <- function(x, digits = max(5, .Options$digits - 3),
 	signif.stars = FALSE, ...)
 {
 	cat("\nCall:", deparse(x$call),	sep = "", fill=TRUE)
+       if (x$type == "error") if (isTRUE(all.equal(x$lambda, x$interval[1])) ||
+            isTRUE(all.equal(x$lambda, x$interval[2]))) 
+            warning("lambda on interval bound - results should not be used")
+       if (x$type == "lag" || x$type == "mixed")
+            if (isTRUE(all.equal(x$rho, x$interval[1])) ||
+            isTRUE(all.equal(x$rho, x$interval[2]))) 
+            warning("rho on interval bound - results should not be used")
 	cat("\nResiduals:\n")
 	resid <- residuals(x)
 	nam <- c("Min", "1Q", "Median", "3Q", "Max")
-	rq <- if (length(dim(resid)) == 2) 
+	rq <- if (length(dim(resid)) == 2L) 
 		structure(apply(t(resid), 1, quantile), dimnames = list(nam, 
 			dimnames(resid)[[2]]))
 	else structure(quantile(resid), names = nam)
@@ -264,7 +278,7 @@ print.summary.sarlm <- function(x, digits = max(5, .Options$digits - 3),
 			digits)), ", p-value: ", format.pval(x$Wald1$p.value, 
 			digits), "\n", sep="")
 		}
-	} else if (x$type == "sac") {
+	} else if (x$type == "sac" || x$type == "sacmixed") {
 		cat("\nRho: ", format(signif(x$rho, digits)), "\n",
                     sep="")
                 if (!is.null(x$rho.se)) {
@@ -325,7 +339,7 @@ print.summary.sarlm <- function(x, digits = max(5, .Options$digits - 3),
                         "\n", sep="")
 		}
         }
-	if (x$type != "error" && x$type != "sac" && x$ase) {
+	if (x$type == "lag" && x$ase) {
 		cat("LM test for residual autocorrelation\n")
 		cat("test value: ", format(signif(x$LMtest, digits)),
 			", p-value: ", format.pval((1 - pchisq(x$LMtest, 1)), 
